@@ -2,7 +2,7 @@
 # │ PROJECT IMPORTS                                                                    │
 # └────────────────────────────────────────────────────────────────────────────────────┘
 
-from pyob.ob import Ob
-from pyob.ob_set import ObSet
-from pyob.ob_store import ObStore
+from pyob.pyob import PyOb
+from pyob.pyob_set import PyObSet
+from pyob.pyob_store import PyObStore
 from pyob.tools import localize
