@@ -4,9 +4,13 @@
 
 from pyob.tools.convert_ import convert_string_to_pascal_case
 from pyob.tools.filter_ import filter_and, filter_by_key, filter_by_keys, filter_or
-from pyob.tools.is_ import is_iterable, is_ob, is_ob_set
+from pyob.tools.is_ import is_iterable, is_pyob, is_pyob_set
 from pyob.tools.localize_ import localize
 from pyob.tools.remove_ import remove_duplicates
 from pyob.tools.split_ import split_camel_case
-from pyob.tools.traverse_ import traverse_pyob_ancestors, traverse_pyob_relatives
+from pyob.tools.traverse_ import (
+    traverse_pyob_ancestors,
+    traverse_pyob_descendants,
+    traverse_pyob_relatives,
+)
 from pyob.tools.validate_ import validate_and_index_pyob_attribute_value
